@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-06-16'; # DATE
-our $VERSION = '1.006'; # VERSION
+our $DATE = '2016-08-20'; # DATE
+our $VERSION = '1.007'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -18,7 +18,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.006 of Bencher (from Perl distribution Bencher), released on 2016-06-16.
+This document describes version 1.007 of Bencher (from Perl distribution Bencher), released on 2016-08-20.
 
 =head1 SYNOPSIS
 
@@ -358,6 +358,18 @@ C<func.module_versions>, for extra information. An example to put here are
 modules that contain/produce datasets that get benchmarked, because the data
 might differ from version to version.
 
+=item * env_hashes (array of hash)
+
+With this property, you can permute multiple sets of environment variables.
+Suppose you want to benchmark each participant when running under environment
+variables FOO=0, FOO=1, and FOO=2. You can specify:
+
+ env_hashes => [
+     {FOO=>0},
+     {FOO=>1},
+     {FOO=>2},
+ ]
+
 =item * on_failure (str, "skip"|"die")
 
 For a command participant, failure means non-zero exit code. For a Perl-code
@@ -523,6 +535,8 @@ feature.
 
 L<bencher>
 
+C<Bencher::Manual::*>
+
 B<BenchmarkAnything>. There are lot of overlaps of goals between Bencher and
 this project. I hope to reuse or interoperate parts of BenchmarkAnything, e.g.
 storing Bencher results in a BenchmarkAnything storage backend, sending Bencher
